<!---
<fusedoc fuse="act_generate.cfm" version="2.0" language="ColdFusion">
	<responsibilities>
		I take the intermediate representation of the app's fusedocs
		and generate all the static HTML files
	</responsibilities>
	<io>
		<in>
			<structure name="circuits" comments="the target app's circuit structure" />
			<structure name="fusedocs">
				<structure name="*" comments="the intermediate representation of a circuit">
					<structure name="coreFiles" />
					<structure name="fuses" />
					<structure name="fuseactions" />
				</structure>
			</structure>
		</in>
		<out>
		</out>
	</io>
</fusedoc>
--->

<!--- build a reverse circuits struct --->
<cfscript>
	circuits_rev = StructNew();
	for (c in circuits) {
		circuits_rev[circuits[c]] = c;
	}
</cfscript>

<!--- ensure we have the directory tree we need --->
<cfif NOT directoryExists(attributes.outputdir)>
	<cfdirectory action="create"
		directory="#attributes.outputdir#" />
</cfif>
<cfloop collection="#circuits_rev#" item="path">
	<cfif NOT directoryExists("#attributes.outputdir##request.os.delimiter##path#")>
		<cfdirectory action="create"
			directory="#attributes.outputdir##request.os.delimiter##path#" />
	</cfif>
</cfloop>

<!--- index.html--->
<cffile action="write"
	file="#attributes.outputdir##request.os.delimiter#index.html"
	output="#request.html.index#"
	addnewline="0"
	mode="664" />

<!--- stylesheet.css --->
<cffile action="write"
	file="#attributes.outputdir##request.os.delimiter#stylesheet.css"
	output="#request.css.stylesheet#"
	addnewline="0"
	mode="664" />

<cfoutput>

<!--- app-summary.html --->
<cfsavecontent variable="temp">
#replace(request.html.doc_open, "<!rootpath!>", "")#
#replace(request.html.app_header, "<!rootpath!>", "")#
<h1>#attributes.appname#</h1>
<h2>Circuit List</h2>
<cfloop list="#listSort(structKeyList(circuits_rev), 'text')#" index="circuit">
	#repeatString("&nbsp; ", listLen(circuit, request.os.delimiter) * 3)#<a href="#circuit#/circuit-summary.html">#circuits_rev[circuit]#</a><br /></cfloop>
#replace(request.html.app_header, "<!rootpath!>", "")#
#request.html.doc_close#
</cfsavecontent>

<cffile action="write"
	file="#attributes.outputdir##request.os.delimiter#app-summary.html"
	output="#temp#"
	addnewline="0"
	mode="664" />

<!--- circuit-list.html --->
<cfsavecontent variable="temp">
#replace(request.html.doc_open, "<!rootpath!>", "")#
<p><b>#attributes.appname#</b><br>
<a href="all-fuses.html" target="fuse-list">All Fuses</a>
</p>

<p><b>Circuits</b><br>
<cfloop list="#listSort(structKeyList(circuits_rev), 'text')#" index="circuit">
	#repeatString("&nbsp; ", listLen(circuit, request.os.delimiter))#<a href="#circuit#/fuse-list.html" target="fuse-list">#circuits_rev[circuit]#</a><br /></cfloop>
</p>
#request.html.doc_close#
</cfsavecontent>

<cffile action="write"
	file="#attributes.outputdir##request.os.delimiter#circuit-list.html"
	output="#temp#"
	addnewline="0"
	mode="664" />

<!--- for the all-fuses.html page --->
<cfset all_fuses = arrayNew(1) />

<cfloop collection="#fusedocs#" item="circuit">
	Generating Circuit #circuit#<br>
	<cfset rootpath = repeatString('../', listLen(circuits[circuit], '/')) />
	<!--- initialize circuit-summary --->
	<cfset circuit_summary = replace(request.html.doc_open, "<!rootpath!>", rootpath, "all") & chr(10) &
		replace(request.html.circuit_header, "<!rootpath!>", rootpath, "all") & chr(10) &
		"<h1>#ucase(left(circuit, 1))##lcase(removeChars(circuit, 1, 1))#</h1>" />
	<!--- initialize fuse-list --->
	<cfset fuse_list = replace(request.html.doc_open, "<!rootpath!>", rootpath, "all") & chr(10) &
		"<a href=""circuit-summary.html"" target=""main""><b>#ucase(left(circuit, 1))##lcase(removeChars(circuit, 1, 1))#</b></a><br />" />
	
	<!--- write the fuseactions to the circuit-summary page --->
	<cfif structKeyExists(fusedocs[circuit], "fuseactions")>
		<cfset circuit_summary = circuit_summary & chr(10) &
			"<h2>Available Fuseactions</h2>" & chr(10) &
			"<ul>" />
		<cfloop list="#listSort(structKeyList(fusedocs[circuit].fuseactions), 'textnocase')#" index="fa">
			<cfset circuit_summary = circuit_summary & chr(10) &
				"<li>#fa#</li>" />
		</cfloop>
		<cfset circuit_summary = circuit_summary & chr(10) &
			"</ul>" />
	</cfif>

	
	<!--- add the core files to both lists --->
	<cfif structKeyExists(fusedocs[circuit], "coreFiles")>
		<cfset circuit_summary = circuit_summary & chr(10) &
			"<h2>Core Files</h2>" & chr(10) &
			"<ul>" />
		<cfset fuse_list = fuse_list & chr(10) &
			"<p><b>Core Files</b><br>" />
		<!--- loop the fuses --->
		<cfloop list="#listSort(structKeyList(fusedocs[circuit].coreFiles), 'textnocase')#" index="fuse">
			&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; Generating #fuse#<br>
			<cfset fusefile = listDeleteAt(fuse, listLen(fuse, '.'), '.') & ".html" />
			<!--- add to the global list --->
			<cfset arrayAppend(all_fuses, "#fuse#:#circuits[circuit]#:#fusefile#:corefile") />
			<cfset circuit_summary = circuit_summary & chr(10) &
				"<li><a href=""#fusefile#"" class=""corefile"">#fuse#</a></li>" />
			<cfset fuse_list = fuse_list & chr(10) &
				"<a href=""#fusefile#"" target=""main"" class=""corefile"">#fuse#</a><br />" />
			<!--- write the fuse file --->
			<cfset writefuse(fuse, fusefile, circuits[circuit], fusedocs[circuit].coreFiles[fuse]) />
		</cfloop>
		<cfset circuit_summary = circuit_summary & chr(10) &
			"</ul>" />
		<cfset fuse_list = fuse_list & chr(10) &
			"</p>" />
	</cfif>
	
	<!--- add the 'normal' fuses to both lists --->
	<cfif structKeyExists(fusedocs[circuit], "fuses")>
		<cfset circuit_summary = circuit_summary & chr(10) &
			"<h2>Fuses</h2>" & chr(10) &
			"<ul>" />
		<cfset fuse_list = fuse_list & chr(10) &
			"<p><b>Fuses</b><br>" />
		<!--- loop the fuses --->
		<cfloop list="#listSort(structKeyList(fusedocs[circuit].fuses), 'textnocase')#" index="fuse">
			&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; Generating #fuse#<br>
			<cfset fusefile = listDeleteAt(fuse, listLen(fuse, '.'), '.') & ".html" />
			<!--- add to the global list --->
			<cfset arrayAppend(all_fuses, "#fuse#:#circuits[circuit]#:#fusefile#:fuse") />
			<cfset circuit_summary = circuit_summary & chr(10) &
				"<li><a href=""#fusefile#"" class=""fuse"">#fuse#</a></li>" />
			<cfset fuse_list = fuse_list & chr(10) &
				"<a href=""#fusefile#"" target=""main"" class=""fuse"">#fuse#</a><br />" />
			<!--- write the fuse file --->
			<cfset writefuse(fuse, fusefile, circuits[circuit], fusedocs[circuit].fuses[fuse]) />
		</cfloop>
		<cfset circuit_summary = circuit_summary & chr(10) &
			"</ul>" />
		<cfset fuse_list = fuse_list & chr(10) &
			"</p>" />
	</cfif>
	
	<!--- close out the files --->
	<cfset circuit_summary = circuit_summary & chr(10) &
		replace(request.html.circuit_header, "<!rootpath!>", rootpath, "all") & chr(10) &
		request.html.doc_close />
	<cfset fuse_list = fuse_list & chr(10) &
		request.html.doc_close />
	<!--- write circuit-summary.html --->
	<cffile action="write"
		file="#attributes.outputdir##request.os.delimiter##circuits[circuit]##request.os.delimiter#circuit-summary.html"
		output="#circuit_summary#"
		addnewline="0"
		mode="664" />
	<!--- write fuse-list.html --->
	<cffile action="write"
		file="#attributes.outputdir##request.os.delimiter##circuits[circuit]##request.os.delimiter#fuse-list.html"
		output="#fuse_list#"
		addnewline="0"
		mode="664" />
</cfloop>

<!--- finsh all-fuses.html --->
<cfset arraySort(all_fuses, "textnocase") />

<cfsavecontent variable="temp">
#replace(request.html.doc_open, "<!rootpath!>", "")#
<b>All Fuses</b><br>
<cfloop from="1" to="#arrayLen(all_fuses)#" index="i">
	<a href="#listGetAt(all_fuses[i], 2, ':')#/#listGetAt(all_fuses[i], 3, ':')#" target="main" class="#listLast(all_fuses[i], ':')#">#listFirst(all_fuses[i], ':')#</a><br /></cfloop>
#request.html.doc_close#
</cfsavecontent>

<cffile action="write"
	file="#attributes.outputdir##request.os.delimiter#all-fuses.html"
	output="#temp#"
	addnewline="0"
	mode="664" />

</cfoutput>

