<!---
<fusedoc fuse="udf_processfile.cfm" version="2.0" language="ColdFusion">
	<responsibilities>
		i process a single file into it's intermediate representation
	</responsibilities>
	<io>
		<in>
			<string name="filename" scope="arguments" />
		</in>
		<out>
			<string name="_unknown_" comments="the parsed fusedoc XML document" />
		</out>
	</io>
</fusedoc>
--->

<cffunction name="processFile" returnType="string" output="true">
	<cfargument name="filename" type="string" required="true" />

	<cfset var fusedoc = "" />
	<cfset var start = 0 />
	<cfset var endstruct = structNew() />
	<cfset var filecontent = "" />

	<cffile action="read"
		file="#filename#"
		variable="filecontent" />

	<cftry>
		<cfset start = findNoCase("<fusedoc", filecontent) />
		<!--- if we don't have a fusedoc in there, return the empty struct --->
		<cfif start LTE 0>
			<cfthrow type="InvalidFusedocStructureException"
				message="No opening tag was found" />
		</cfif>

		<cfset endstruct = REfindNoCase("</fusedoc[^>]*>", filecontent, start, true) />
		<cfif endstruct.pos[1] EQ 0>
			<cfthrow type="InvalidFusedocStructureException"
				message="No closing tag was found" />
		</cfif>

		<!--- get the fusedoc and turn it into an XML document --->
		<cfset fusedoc = trim(mid(filecontent, start - 1, endstruct.pos[1] + endstruct.len[1] - start + 1)) />

		<cfif NOT findNoCase("<responsibilities", fusedoc)>
			<cfthrow type="InvalidFusedocStructureException"
				message="The 'reponsibilities' node is required in all fusedocs, and this fuse appears not to have one." />
		</cfif>

		<cftry>
			<cfset fusedoc = xmlParse(fusedoc) />
			<cfcatch type="Expression">
				<cfthrow type="InvalidFusedocStructureException"
					message="#htmlEditFormat(cfcatch.message)#" />
			</cfcatch>
		</cftry>

		<cfcatch type="InvalidFusedocStructureException">
			<cfoutput><span class="error">Error parsing <code>#arguments.filename#</code>'s fusedoc<br />
			&nbsp; &nbsp; #cfcatch.message#</span><br /></cfoutput>
			<cfset fusedoc = xmlParse("<fusedoc><responsibilities>Unknown.</responsibilities>" & chr(10) &
				"<properties><note author=""Fusedoc Parser"" date=""#dateformat(now(), 'dd mmm yyyy')#"">" & chr(10) &
				"The fusedoc in the file is invalid or missing.  Please correct the fusedoc and rerun the documentation tool.<br />" & chr(10) &
				"<br />" & chr(10) &
				"Here is the original error message:<br />" & chr(10) &
				cfcatch.message & chr(10) &
				"</note></properties></fusedoc>") />
		</cfcatch>
	</cftry>

	<cfreturn fusedoc />
</cffunction>
