<!--
<fusedoc fuse="detail.xsl" version="2.0" language="XSL">
	<responsibilities>
		I am an XSL stylesheet that translates a fusedoc 2.0 document
		into complete HTML documentation.
	</responsibilities>
</fusedoc>
-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" />
<xsl:template match="/">
	<xsl:if test="count(fusedoc/io/in)">
		<table cellpadding="3" cellspacing="0" border="1" width="100%"><tr><th colspan="2">Input Variables Detail</th></tr></table>
		<xsl:apply-templates select="fusedoc/io/in" />
		<br />
	</xsl:if>

	<xsl:if test="count(fusedoc/io/out)">
		<table cellpadding="3" cellspacing="0" border="1" width="100%"><tr><th colspan="2">Output Variables Detail</th></tr></table>
		<xsl:apply-templates select="fusedoc/io/out" />
		<br />
	</xsl:if>
</xsl:template>

<xsl:template match="in">
	<xsl:apply-templates select="./node()" />
</xsl:template>

<xsl:template match="out">
	<xsl:apply-templates select="./node()" />
</xsl:template>

<xsl:template match="string|number|boolean|datetime|list">
	<xsl:variable name="scope" select="@scope" />
	<xsl:variable name="name" select="@name" />
	<h3><a name="{$scope}.{$name}"></a><xsl:if test="string-length(@scope)!=0"><xsl:value-of select="@scope" />.</xsl:if><xsl:value-of select="@name" /></h3>
	<code><xsl:value-of select="local-name(.)" /></code>
	<blockquote>
		<xsl:if test="string-length(@comments)!=0"><xsl:value-of select="@comments" /><br /></xsl:if>
		<u>Attributes:</u>
		<table>
			<xsl:if test="string-length(@mask)!=0"><tr><td align="right" valign="top"><b><code>mask:</code></b></td><td><xsl:value-of select="@mask" /></td></tr></xsl:if>
			<xsl:if test="string-length(@precision)!=0"><tr><td align="right" valign="top"><b><code>precision:</code></b></td><td><xsl:value-of select="@precision" /></td></tr></xsl:if>
			<xsl:if test="string-length(@delims)!=0"><tr><td align="right" valign="top"><b><code>delims:</code></b></td><td><xsl:value-of select="@delims" /></td></tr></xsl:if>
			<xsl:if test="string-length(@optional)!=0"><tr><td align="right" valign="top"><b><code>optional:</code></b></td><td><xsl:value-of select="@optional" /></td></tr></xsl:if>
			<xsl:if test="string-length(@onCondition)!=0"><tr><td align="right" valign="top"><b><code>onCondition:</code></b></td><td><xsl:value-of select="@onCondition" /></td></tr></xsl:if>
			<xsl:if test="string-length(@editable)!=0"><tr><td align="right" valign="top"><b><code>editable:</code></b></td><td><xsl:value-of select="@editable" /></td></tr></xsl:if>
			<xsl:if test="string-length(@passthrough)!=0"><tr><td align="right" valign="top"><b><code>passthrough:</code></b></td><td><xsl:value-of select="@passthrough" /></td></tr></xsl:if>
			<xsl:if test="string-length(@format)!=0"><tr><td align="right" valign="top"><b><code>format:</code></b></td><td><xsl:value-of select="@format" /></td></tr></xsl:if>
			<xsl:if test="string-length(@default)!=0"><tr><td align="right" valign="top"><b><code>default:</code></b></td><td><xsl:value-of select="@default" /></td></tr></xsl:if>
		</table>
	</blockquote>
	<hr />
</xsl:template>

<xsl:template match="cookie">
	<xsl:variable name="name" select="@name" />
	<h3><a name="cookie.{$name}"></a>cookie.<xsl:value-of select="@name" /></h3>
	<code>cookie</code>
	<blockquote>
		<xsl:if test="string-length(@comments)!=0"><xsl:value-of select="@comments" /><br /></xsl:if>
		<u>Attributes:</u>
		<table>
			<xsl:if test="string-length(@domain)!=0"><tr><td align="right" valign="top"><b><code>domain:</code></b></td><td><xsl:value-of select="@domain" /></td></tr></xsl:if>
			<xsl:if test="string-length(@expires)!=0"><tr><td align="right" valign="top"><b><code>expires:</code></b></td><td><xsl:value-of select="@expires" /></td></tr></xsl:if>
			<xsl:if test="string-length(@path)!=0"><tr><td align="right" valign="top"><b><code>path:</code></b></td><td><xsl:value-of select="@path" /></td></tr></xsl:if>
			<xsl:if test="string-length(@optional)!=0"><tr><td align="right" valign="top"><b><code>optional:</code></b></td><td><xsl:value-of select="@optional" /></td></tr></xsl:if>
			<xsl:if test="string-length(@onCondition)!=0"><tr><td align="right" valign="top"><b><code>onCondition:</code></b></td><td><xsl:value-of select="@onCondition" /></td></tr></xsl:if>
			<xsl:if test="string-length(@editable)!=0"><tr><td align="right" valign="top"><b><code>editable:</code></b></td><td><xsl:value-of select="@editable" /></td></tr></xsl:if>
			<xsl:if test="string-length(@default)!=0"><tr><td align="right" valign="top"><b><code>default:</code></b></td><td><xsl:value-of select="@default" /></td></tr></xsl:if>
		</table>
	</blockquote>
	<hr />
</xsl:template>

<xsl:template match="array|structure|recordset|function">
	<xsl:variable name="scope" select="@scope" />
	<xsl:variable name="name" select="@name" />
	<h3><a name="{$scope}.{$name}"></a><xsl:if test="string-length(@scope)!=0"><xsl:value-of select="@scope" />.</xsl:if><xsl:value-of select="@name" /></h3>
	<code><xsl:value-of select="local-name(.)" /></code>
	<blockquote>
		<xsl:if test="string-length(@comments)!=0"><xsl:value-of select="@comments" /><br /></xsl:if>
		<dl>
			<dt><u>Attributes:</u></dt>
			<dd>
				<table border="0">
					<xsl:if test="string-length(@primarykeys)!=0"><tr><td align="right" valign="top"><b><code>primarykeys:</code></b></td><td><xsl:value-of select="@primarykeys" /></td></tr></xsl:if>
					<xsl:if test="string-length(@returntype)!=0"><tr><td align="right" valign="top"><b><code>returntype:</code></b></td><td><xsl:value-of select="@returntype" /></td></tr></xsl:if>
					<xsl:if test="string-length(@optional)!=0"><tr><td align="right" valign="top"><b><code>optional:</code></b></td><td><xsl:value-of select="@optional" /></td></tr></xsl:if>
					<xsl:if test="string-length(@onCondition)!=0"><tr><td align="right" valign="top"><b><code>onCondition:</code></b></td><td><xsl:value-of select="@onCondition" /></td></tr></xsl:if>
					<xsl:if test="string-length(@editable)!=0"><tr><td align="right" valign="top"><b><code>editable:</code></b></td><td><xsl:value-of select="@editable" /></td></tr></xsl:if>
					<xsl:if test="string-length(@passthrough)!=0"><tr><td align="right" valign="top"><b><code>passthrough:</code></b></td><td><xsl:value-of select="@passthrough" /></td></tr></xsl:if>
					<xsl:if test="string-length(@format)!=0"><tr><td align="right" valign="top"><b><code>format:</code></b></td><td><xsl:value-of select="@format" /></td></tr></xsl:if>
				</table>
			</dd>
			<xsl:if test="count(./node())&gt;0">
				<dt><u><xsl:if test="local-name(.)='function'">Parameters</xsl:if><xsl:if test="local-name(.)!='function'">Sub-Elements</xsl:if></u></dt>
				<dd>
					<table cellpadding="3" cellspacing="0" border="1"><tr><td>
						<xsl:apply-templates select="./node()" />
					</td></tr></table>
				</dd>
			</xsl:if>
		</dl>
	</blockquote>
	<hr />
</xsl:template>

</xsl:stylesheet>
