<!--
<fusedoc fuse="summary.xsl" version="2.0" language="XSL">
	<responsibilities>
		I am an XSL stylesheet that generates summary documentation from
		a fusedoc 2.0 document
	</responsibilities>
</fusedoc>
-->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html" />
<xsl:template match="/">
	<h2>Responsibilities</h2>
	<p><xsl:value-of select="fusedoc/responsibilities" />
	</p>

	<xsl:if test="count(fusedoc/properties/note)">
		<table cellpadding="3" cellspacing="0" border="1" width="100%">
			<tr><th colspan="2">Notes</th></tr>
			<xsl:apply-templates select="fusedoc/properties/note" />
		</table>
		<br />
	</xsl:if>

	<xsl:if test="count(fusedoc/properties/property)">
		<table cellpadding="3" cellspacing="0" border="1" width="100%">
			<tr><th colspan="2">Properties</th></tr>
			<xsl:apply-templates select="fusedoc/properties/property" />
		</table>
		<br />
	</xsl:if>

	<xsl:if test="count(fusedoc/properties/history)">
		<table cellpadding="3" cellspacing="0" border="1" width="100%">
			<tr><th colspan="2">History</th></tr>
			<xsl:apply-templates select="fusedoc/properties/history" />
		</table>
		<br />
	</xsl:if>

	<xsl:if test="count(fusedoc/io/in)">
		<table cellpadding="3" cellspacing="0" border="1" width="100%">
			<tr><th colspan="2">Input Variables Summary</th></tr>
			<xsl:apply-templates select="fusedoc/io/in" />
		</table>
		<br />
	</xsl:if>

	<xsl:if test="count(fusedoc/io/out)">
		<table cellpadding="3" cellspacing="0" border="1" width="100%">
			<tr><th colspan="2">Output Variables Summary</th></tr>
			<xsl:apply-templates select="fusedoc/io/out" />
		</table>
		<br />
	</xsl:if>

	<xsl:if test="count(fusedoc/io/throw)">
		<table cellpadding="3" cellspacing="0" border="1" width="100%">
			<tr><th colspan="2">Exceptions</th></tr>
			<xsl:apply-templates select="fusedoc/io/throws" />
		</table>
		<br />
	</xsl:if>
</xsl:template>

<xsl:template match="note">
	<tr>
		<td>
			<xsl:value-of select="@author" /> - <i><xsl:value-of select="@date" /></i><br />
			<div class="indent"><xsl:value-of select="." /></div>
		</td>
	</tr>
</xsl:template>

<xsl:template match="property">
	<tr>
		<td align="right" valign="top" nowrap="nowrap"><b><xsl:value-of select="@name" /></b></td>
		<td width="100%"><xsl:value-of select="@value" /></td>
	</tr>
</xsl:template>

<xsl:template match="history">
	<tr>
		<td align="right" valign="top" nowrap="nowrap"><xsl:value-of select="@type" /></td>
		<td width="100%">
			<xsl:value-of select="@author" /> - <i><xsl:value-of select="@date" /></i><br />
			<div class="indent"><xsl:value-of select="." /></div>
		</td>
	</tr>
</xsl:template>

<xsl:template match="in">
	<xsl:apply-templates select="./node()" />
</xsl:template>

<xsl:template match="out">
	<xsl:apply-templates select="./node()" />
</xsl:template>

<xsl:template match="string|number|boolean|datetime|list">
	<xsl:variable name="scope" select="@scope" />
	<xsl:variable name="name" select="@name" />
	<tr>
		<td align="right" valign="top" nowrap="nowrap"><xsl:value-of select="local-name(.)" /></td>
		<td width="100%">
			<xsl:if test="string-length(@scope)!=0"><xsl:value-of select="@scope" />.</xsl:if><a href="#{$scope}.{$name}"><xsl:value-of select="@name" /></a>
			<div class="indent"><xsl:value-of select="@comments" /></div>
		</td>
	</tr>
</xsl:template>

<xsl:template match="cookie">
	<xsl:variable name="name" select="@name" />
	<tr>
		<td align="right" valign="top" nowrap="nowrap">cookie</td>
		<td width="100%">
			cookie.<a href="#cookie.{$name}"><xsl:value-of select="@name" /></a>
			<div class="indent"><xsl:value-of select="@comments" /></div>
		</td>
	</tr>
</xsl:template>

<xsl:template match="array|structure|recordset|function">
	<xsl:variable name="scope" select="@scope" />
	<xsl:variable name="name" select="@name" />
	<tr>
		<td align="right" valign="top" nowrap="nowrap"><xsl:value-of select="local-name(.)" /></td>
		<td width="100%">
			<xsl:if test="string-length(@scope)!=0"><xsl:value-of select="@scope" />.</xsl:if><a href="#{$scope}.{$name}"><xsl:value-of select="@name" /></a>
			<div class="indent"><xsl:value-of select="@comments" /></div>
		</td>
	</tr>
</xsl:template>

<xsl:template match="throws">
	<tr>
		<td align="right" valign="top" nowrap="nowrap"><xsl:value-of select="@type" /></td>
		<td width="100%"><xsl:value-of select="@cause" /></td>
	</tr>
</xsl:template>

</xsl:stylesheet>
